Learn R Programming

gctsc (version 0.1.3)

print.gctsc: Print a gctsc Model Object

Description

Displays the call, estimation method, parameter estimates, and likelihood information.

Usage

# S3 method for gctsc
print(x, digits = max(3, getOption("digits") - 3), ...)

Value

Returns the object x invisibly. Called for its side effect of printing a formatted summary of the model fit.

Arguments

x

An object of class gctsc.

digits

Number of significant digits to display.

...

Ignored. Included for S3 method compatibility.