| arma.cormat | R Documentation |
Constructs an ARMA(p,q) correlation structure for use in
Gaussian and Student–t copula count time series models.
arma.cormat(p = 0, q = 0, tau.lower = NULL, tau.upper = NULL)
p |
Non-negative integer specifying the autoregressive (AR) order. |
q |
Non-negative integer specifying the moving-average (MA) order. The model ARMA(0,0) is not supported. |
tau.lower |
Optional numeric vector of length |
tau.upper |
Optional numeric vector of length |
The ARMA model specifies the dependence structure of the latent copula process.
The ARMA parameters must define a stationary and invertible process. These conditions are enforced during model fitting.
An object of class "arma.gctsc" and "cormat.gctsc"
containing:
npar: Number of ARMA parameters (p + q).
od: Integer vector c(p, q).
start: Function to compute starting values from data,
typically using arima.
lower, upper: Parameter bounds.
gctsc,
poisson.marg,
predict.gctsc
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.