Learn R Programming

gctsc (version 0.1.3)

arma.cormat: ARMA Correlation Structure for Copula Time Series

Description

Constructs a correlation structure object for use in Gaussian copula time series models with autoregressive moving average (ARMA) dependence.

Usage

arma.cormat(p = 0, q = 0, tau.lower = NULL, tau.upper = NULL)

Value

An object of class "arma.gctsc" and "cormat.gctsc", containing:

npar

Number of ARMA parameters.

od

A length-2 vector c(p, q) giving the AR and MA order.

start

Function to compute starting values from data using arima.

Arguments

p

Integer. AR order (non-negative).

q

Integer. MA order (non-negative).

tau.lower

Optional vector of lower bounds for the ARMA parameters.

tau.upper

Optional vector of upper bounds for the ARMA parameters.

See Also

gctsc, poisson.marg, predict.gctsc