Constructs a correlation structure object for use in Gaussian copula time series models with autoregressive moving average (ARMA) dependence.
arma.cormat(p = 0, q = 0, tau.lower = NULL, tau.upper = NULL)An object of class "arma.gctsc" and "cormat.gctsc", containing:
Number of ARMA parameters.
A length-2 vector c(p, q) giving the AR and MA order.
Function to compute starting values from data using arima.
Integer. AR order (non-negative).
Integer. MA order (non-negative).
Optional vector of lower bounds for the ARMA parameters.
Optional vector of upper bounds for the ARMA parameters.
gctsc, poisson.marg, predict.gctsc