Learn R Programming

gctsc (version 0.1.3)

gctsc.opts: Set Options for Gaussian Copula Time Series Model

Description

Creates a control list for simulation and likelihood approximation in the Gaussian copula model, including the random seed and Monte Carlo settings.

Usage

gctsc.opts(seed = NULL, M = 1000, ...)

Value

A list with components:

seed

Integer. The random seed used.

M

Integer. Number of Monte Carlo samples.

opt

A function used internally by gctsc() to perform optimization of the approximate log-likelihood.

Arguments

seed

Integer. Random seed for reproducibility (default: a random integer between 1 and 100000).

M

Integer. Number of Monte Carlo samples used in the likelihood approximation (default: 1000).

...

Ignored. Included for S3 method compatibility.