Creates a control list for simulation and likelihood approximation in the Gaussian copula model, including the random seed and Monte Carlo settings.
gctsc.opts(seed = NULL, M = 1000, ...)A list with components:
seedInteger. The random seed used.
MInteger. Number of Monte Carlo samples.
optA function used internally by gctsc() to
perform optimization of the approximate log-likelihood.
Integer. Random seed for reproducibility (default: a random integer between 1 and 100000).
Integer. Number of Monte Carlo samples used in the likelihood approximation (default: 1000).
Ignored. Included for S3 method compatibility.