Learn R Programming

gctsc (version 0.1.3)

marginal.gctsc: Marginal Models for Copula Time Series

Description

The following marginal models are currently available:

poisson.marg(link = "log")

Poisson distribution.

negbin.marg(link = "log")

Negative binomial distribution.

binom.marg(link = "logit", size)

Binomial distribution with fixed number of trials.

bbinom.marg(link = "logit", size)

Beta-binomial with overdispersion.

zip.marg(link = "log")

Zero-inflated Poisson model.

zib.marg(link = "logit", size)

Zero-inflated binomial.

zibb.marg(link = "logit", size)

Zero-inflated beta-binomial with separate covariates for zero inflation.

Usage

poisson.marg(link = "identity", lambda.lower = NULL, lambda.upper = NULL)

binom.marg(link = "logit", size = NULL, lambda.lower = NULL, lambda.upper = NULL)

zib.marg(link = "logit", size = NULL, lambda.lower = NULL, lambda.upper = NULL)

negbin.marg(link = "identity", lambda.lower = NULL, lambda.upper = NULL)

zip.marg(link = "identity", lambda.lower = NULL, lambda.upper = NULL)

bbinom.marg(link = "logit", size, lambda.lower = NULL, lambda.upper = NULL)

zibb.marg(link = "logit", size, lambda.lower = NULL, lambda.upper = NULL)

Value

A list of class "marginal.gctsc" representing the marginal model.

Arguments

link

The link function for the mean (e.g., "log", "logit", "identity").

lambda.lower

Optional lower bounds on parameters.

lambda.upper

Optional upper bounds on parameters.

size

Number of trials (for binomial-type models).

Details

These functions define the marginal distributions used in copula-based count time series models.

Each marginal constructor returns an object of class "marginal.gctsc" which defines:

  • start: a function to compute starting values.

  • npar: number of parameters.

  • bounds: truncation bounds on the latent Gaussian.

These marginals are designed to work with gctsc() and its related methods.

References

Cribari-Neto, F. and Zeileis, A. (2010). Beta regression in R. Journal of Statistical Software, 34(2): 1–24.

Ferrari, S.L.P. and Cribari-Neto, F. (2004). Beta regression for modeling rates and proportions. Journal of Applied Statistics, 31(7): 799–815.

Masarotto, G. and Varin, C. (2012). Gaussian copula marginal regression. Electronic Journal of Statistics, 6: 1517–1549.

See Also

gctsc, predict.gctsc, arma.cormat

Examples

Run this code
poisson.marg(link = "identity")
zibb.marg(link = "logit", size = 24)

Run the code above in your browser using DataLab