Displays the call, estimation method, parameter estimates, and likelihood information.
# S3 method for gctsc
print(x, digits = max(3, getOption("digits") - 3), ...)Returns the object x invisibly.
Called for its side effect of printing a formatted summary of the model fit.
An object of class gctsc.
Number of significant digits to display.
Ignored. Included for S3 method compatibility.